@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2020 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::HSplit;
 
@@ -11,7 +11,7 @@ use base qw( Tickit::Widget::LinearSplit );
 use Tickit::Style;
 use Tickit::RenderBuffer qw( LINE_SINGLE CAP_BOTH );
 
-our $VERSION = '0.28';
+our $VERSION = '0.30';
 
 use Carp;
 
@@ -23,16 +23,15 @@ C<Tickit::Widget::HSplit> - an adjustable horizontal split between two widgets
 
 =head1 SYNOPSIS
 
- use Tickit;
- use Tickit::Widget::HSplit;
- use Tickit::Widget::Static;
+   use Tickit;
+   use Tickit::Widget::HSplit;
+   use Tickit::Widget::Static;
 
- my $hsplit = Tickit::Widget::HSplit->new(
-    top_child    => Tickit::Widget::Static->new( text => "Text above" ),
-    bottom_child => Tickit::Widget::Static->new( text => "Text below" ),
- );
+   my $hsplit = Tickit::Widget::HSplit->new
+      ->set_top_child   ( Tickit::Widget::Static->new( text => "Text above" ) )
+      ->set_bottom_child( Tickit::Widget::Static->new( text => "Text below" ) );
 
- Tickit->new( root => $hsplit )->run;
+   Tickit->new( root => $hsplit )->run;
 
 =head1 DESCRIPTION
 
@@ -93,7 +92,9 @@ use constant VALUE_METHOD => "lines";
 
 =head1 CONSTRUCTOR
 
-=head2 $hsplit = Tickit::Widget::HSplit->new( %args )
+=head2 new
+
+   $hsplit = Tickit::Widget::HSplit->new( %args )
 
 Constructs a new C<Tickit::Widget::HSplit> object.
 
@@ -105,7 +106,10 @@ Takes the following named arguments
 
 =item bottom_child => WIDGET
 
-Child widgets to use
+Child widgets to use.
+
+These options are now discouraged in favour of the L</set_top_child> and
+L</set_bottom_child> methods.
 
 =back
 
@@ -118,8 +122,11 @@ sub new
 
    my $self = $class->SUPER::new( %args );
 
-   $self->set_top_child   ( $args{top_child}    ) if $args{top_child};
-   $self->set_bottom_child( $args{bottom_child} ) if $args{bottom_child};
+   Carp::carp( "The 'top_child' constructor argument to $class is discouraged; use ->set_top_child instead" ) and
+      $self->set_top_child   ( $args{top_child}    ) if $args{top_child};
+
+   Carp::carp( "The 'bottom_child' constructor argument to $class is discouraged; use ->set_bottom_child instead" ) and
+      $self->set_bottom_child( $args{bottom_child} ) if $args{bottom_child};
 
    return $self;
 }
@@ -148,9 +155,13 @@ sub cols
 
 =cut
 
-=head2 $child = $hsplit->top_child
+=head2 top_child
 
-=head2 $hsplit->set_top_child( $child )
+=head2 set_top_child
+
+   $child = $hsplit->top_child
+
+   $hsplit->set_top_child( $child )
 
 Accessor for the child widget used in the top half of the display.
 
@@ -159,12 +170,26 @@ Accessor for the child widget used in the top half of the display.
 *top_child     = __PACKAGE__->can( "A_child" );
 *set_top_child = __PACKAGE__->can( "set_A_child" );
 
-=head2 $child = $hsplit->bottom_child
+=head2 bottom_child
 
-=head2 $hsplit->set_bottom_child( $child )
+=head2 set_bottom_child
+
+   $child = $hsplit->bottom_child
+
+   $hsplit->set_bottom_child( $child )
 
 Accessor for the child widget used in the bottom half of the display.
 
+These mutators returning the container widget itself making them suitable to
+use as chaining mutators; e.g.
+
+   my $container = Tickit::Widget::HSplit->new( ... )
+      ->set_top_child   ( Tickit::Widget::Box->new ... )
+      ->set_bottom_child( Tickit::Widget::Box->new ... );
+
+These should be preferred over using the C<top_child> and C<bottom_child>
+constructor arguments, which are now discouraged.
+
 =cut
 
 *bottom_child     = __PACKAGE__->can( "B_child" );
